@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2019 Edward F. Valeev
+ *  Copyright (C) 2004-2021 Edward F. Valeev
  *
  *  This file is part of Libint.
  *
@@ -56,6 +56,7 @@
 #include <libint2/util/compressed_pair.h>
 #include <libint2/util/timer.h>
 #include <libint2/cgshellinfo.h>
+#include <libint2/braket.h>
 
 // the engine will be profiled by default if library was configured with
 // --enable-profile
@@ -376,26 +377,6 @@ using core_eval_pack_type =
     __core_eval_pack_type<typename operator_traits<Op>::core_eval_type>;
 }
 
-/// types of shell sets supported by Engine, in chemist notation (i.e. '_'
-/// separates particles)
-/// \warning macro \c BOOST_PP_NBODY_BRAKET_RANK_TUPLE include the ranks of all
-/// brakets in \c BraKet
-///          and macro \c BOOST_PP_NBODY_BRAKET_MAX_INDEX must be equal to the
-///          max value in this enum
-enum class BraKet {
-  x_x = 0,
-  xx_xx,
-  xs_xx,
-  xx_xs,
-  xs_xs,
-  invalid = -1,
-  first_1body_braket = x_x,
-  last_1body_braket = x_x,
-  first_2body_braket = xx_xx,
-  last_2body_braket = xs_xs,
-  first_braket = first_1body_braket,
-  last_braket = last_2body_braket
-};
 #define BOOST_PP_NBODY_BRAKET_MAX_INDEX 4
 
 /// @param[in] braket a BraKet object
@@ -450,7 +431,8 @@ class Engine {
         stack_size_(0),
         lmax_(-1),
         deriv_order_(0),
-        cartesian_shell_normalization_(CartesianShellNormalization::standard) {
+        cartesian_shell_normalization_(CartesianShellNormalization::standard),
+        scale_(1) {
     set_precision(std::numeric_limits<scalar_type>::epsilon());
   }
 
@@ -500,6 +482,7 @@ class Engine {
         lmax_(max_l),
         deriv_order_(deriv_order),
         cartesian_shell_normalization_(CartesianShellNormalization::standard),
+        scale_(1),
         params_(enforce_params_type(oper, params)) {
     set_precision(precision);
     assert(max_nprim > 0);
@@ -526,6 +509,7 @@ class Engine {
         precision_(other.precision_),
         ln_precision_(other.ln_precision_),
         cartesian_shell_normalization_(other.cartesian_shell_normalization_),
+        scale_(other.scale_),
         core_eval_pack_(std::move(other.core_eval_pack_)),
         params_(std::move(other.params_)),
         core_ints_params_(std::move(other.core_ints_params_)),
@@ -533,7 +517,12 @@ class Engine {
         set_targets_(other.set_targets_),
         scratch_(std::move(other.scratch_)),
         scratch2_(other.scratch2_),
-        buildfnptrs_(other.buildfnptrs_) {}
+        buildfnptrs_(other.buildfnptrs_) {
+    // leave other in an unusable (but valid) state
+    other.oper_ = Operator::invalid;
+    other.braket_ = BraKet::invalid;
+    other.scratch2_ = nullptr;
+  }
 
   /// (deep) copy constructor
   Engine(const Engine& other)
@@ -548,6 +537,7 @@ class Engine {
         precision_(other.precision_),
         ln_precision_(other.ln_precision_),
         cartesian_shell_normalization_(other.cartesian_shell_normalization_),
+        scale_(other.scale_),
         core_eval_pack_(other.core_eval_pack_),
         params_(other.params_),
         core_ints_params_(other.core_ints_params_) {
@@ -571,6 +561,7 @@ class Engine {
     precision_ = other.precision_;
     ln_precision_ = other.ln_precision_;
     cartesian_shell_normalization_ = other.cartesian_shell_normalization_;
+    scale_ = other.scale_;
     core_eval_pack_ = std::move(other.core_eval_pack_);
     params_ = std::move(other.params_);
     core_ints_params_ = std::move(other.core_ints_params_);
@@ -579,6 +570,10 @@ class Engine {
     scratch_ = std::move(other.scratch_);
     scratch2_ = other.scratch2_;
     buildfnptrs_ = other.buildfnptrs_;
+    // leave other in an unusable state
+    other.oper_ = Operator::invalid;
+    other.braket_ = BraKet::invalid;
+    other.scratch2_ = nullptr;
     return *this;
   }
 
@@ -595,6 +590,7 @@ class Engine {
     precision_ = other.precision_;
     ln_precision_ = other.ln_precision_;
     cartesian_shell_normalization_ = other.cartesian_shell_normalization_;
+    scale_ = other.scale_;
     core_eval_pack_ = other.core_eval_pack_;
     params_ = other.params_;
     core_ints_params_ = other.core_ints_params_;
@@ -605,7 +601,7 @@ class Engine {
   /// @return the particle rank of the operator
   int operator_rank() const { return rank(oper_); }
 
-  /// @return rank of the braket
+  /// @return rank of the braket (e.g., 2 for (a|b), 3 for (a|bc), etc.)
   int braket_rank() const { return rank(braket_); }
 
   /// @return the operator
@@ -614,6 +610,9 @@ class Engine {
   /// @return the braket
   BraKet braket() const { return braket_; }
 
+  /// @return the order of geometrical derivatives
+  int deriv_order() const { return deriv_order_; }
+
   /// (re)sets operator type to @c new_oper
   /// @param[in] new_oper Operator whose integrals will be computed with the next call to Engine::compute()
   /// @note this resets braket and params to their respective defaults for @c new_oper
@@ -791,6 +790,19 @@ class Engine {
     return *this;
   }
 
+  /// @return the scaling factor by which the target integrals are multiplied
+  scalar_type prescaled_by() const {
+    return scale_;
+  }
+
+  /// @param[in] sc the scaling factor by which the target integrals are multiplied
+  /// @note the default factor is 1
+  /// @return reference to @c this for daisy-chaining
+  Engine& prescale_by(scalar_type sc) {
+    scale_ = sc;
+    return *this;
+  }
+
   /// prints the contents of timers to @c os
   void print_timers(std::ostream& os = std::cout) {
 #ifdef LIBINT2_ENGINE_TIMERS
@@ -875,6 +887,9 @@ class Engine {
   // specifies the normalization convention for Cartesian Gaussians
   CartesianShellNormalization cartesian_shell_normalization_;
 
+  // the target integrals are scaled by this factor (of course it is actually the core integrals that are scaled)
+  scalar_type scale_;
+
   any core_eval_pack_;
 
   /// operator params
@@ -940,11 +955,14 @@ class Engine {
                                                 const Shell& s2, size_t p1,
                                                 size_t p2, size_t oset);
 
+public:
   /// 3-dim array of pointers to help dispatch efficiently based on oper_,
   /// braket_, and deriv_order_
+  /// @note public since 2.7.0 to support efficient dispatch in user code
   __libint2_engine_inline const std::vector<Engine::compute2_ptr_type>&
   compute2_ptrs() const;
 
+private:
   // max_nprim=0 avoids resizing primdata_
   __libint2_engine_inline void initialize(size_t max_nprim = 0);
   // generic _initializer
