@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2019 Edward F. Valeev
+ *  Copyright (C) 2004-2021 Edward F. Valeev
  *
  *  This file is part of Libint.
  *
@@ -785,7 +785,12 @@ BOOST_PP_LIST_FOR_EACH ( BOOST_PP_ONEBODY_MCR1, _, BOOST_PP_ONEBODY_TASK_LIST)
   }
 #else
   iface->to_params(iface->macro_define("MAX_AM",LIBINT_MAX_AM));
-  iface->to_params(iface->macro_define("MAX_AM_default",LIBINT_MAX_AM));
+  for(unsigned int d=0; d<=INCLUDE_ERI; ++d) {
+    std::ostringstream oss;
+    oss << "MAX_AM_default";
+    if (d > 0) oss << d;
+    iface->to_params(iface->macro_define(oss.str(),LIBINT_MAX_AM));
+  }
 #endif
   cparams->print(os);
 
@@ -865,9 +870,9 @@ print_header(std::ostream& os)
 {
   os << "----------------------------------------------" << endl;
   os << " build_libint2: optimizing integrals compiler " << endl;
-  os << "                        by Edward F. Valeev           " << endl;
-  os << "                and ideas by Justin Fermann   "
-     << "                         and Curtis Janssen   " << endl;
+  os << "                        by Edward F. Valeev   " << endl;
+  os << "                and ideas by Justin Fermann   " << endl;
+  os << "                         and Curtis Janssen   " << endl;
   os << "----------------------------------------------" << endl << endl;
 }
 
