@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2019 Edward F. Valeev
+ *  Copyright (C) 2004-2021 Edward F. Valeev
  *
  *  This file is part of Libint.
  *
@@ -28,10 +28,8 @@
 #include <context.h>
 #include <task.h>
 
-using namespace std;
-
 namespace libint2 {
-  /** Libint2Iface is used to generate Libint2 interfaces. The external API consists of 
+  /** Libint2Iface is used to generate Libint2 interfaces. The external API consists of
       the main header file libint2.h (not generated), type definition file libint2_types.h,
       parameter file libint2_params.h, function declarations in libint2_iface.h,
       init/cleanup codes libint2_init.cc, libint2_cleanup.cc, libint2_static_init.cc,
@@ -46,30 +44,30 @@ namespace libint2 {
       Libint2Iface(const SafePtr<CompilationParameters>& cparams,
                    const SafePtr<CodeContext>& ctext);
       ~Libint2Iface();
-      
+
       /// Writes string s to the types header
       void to_types(const std::string& s) {
-        th_ << s << endl;
+        th_ << s << std::endl;
       }
       /// Writes string s to the params header
       void to_params(const std::string& s) {
-        ph_ << s << endl;
+        ph_ << s << std::endl;
       }
       /// Writes string s to the iface header
       void to_iface(const std::string& s) {
-        ih_ << s << endl;
+        ih_ << s << std::endl;
       }
       /// Writes string s to the internal iface header
       void to_int_iface(const std::string& s) {
-        ii_ << s << endl;
+        ii_ << s << std::endl;
       }
       /// Writes string s to the static init code
       void to_static_init(const std::string& s) {
-        si_ << s << endl;
+        si_ << s << std::endl;
       }
       /// Writes string s to the static cleanup code
       void to_static_cleanup(const std::string& s) {
-        sc_ << s << endl;
+        sc_ << s << std::endl;
       }
       /// Writes string s to the Libint_t init code
       //void to_libint_init(const std::string& s) {
@@ -80,30 +78,30 @@ namespace libint2 {
         std::string result("LIBINT2_");  result += label;
         return result;
       }
-      
+
       std::string macro(const std::string& task_label, const std::string& label) {
         std::string result("LIBINT2_");  result += label;  if (task_label != "") { result += "_";  result += task_label; }
         return result;
       }
-      
+
       template <typename T> std::string macro_define(const std::string& label, const T& value) {
         oss_ .str(null_str_);
-        oss_ << "#ifndef " << macro(label) << endl;
-        oss_ << "# define " << macro(label) << " " << value << endl;
-        oss_ << "#endif" << endl;
+        oss_ << "#ifndef " << macro(label) << std::endl;
+        oss_ << "# define " << macro(label) << " " << value << std::endl;
+        oss_ << "#endif" << std::endl;
         return oss_.str();
       }
-      
+
       template <typename T> std::string macro_define(const std::string& task_label, const std::string& label, const T& value) {
         oss_ .str(null_str_);
-        oss_ << "#define " << macro(task_label,label) << " " << value << endl;
+        oss_ << "#define " << macro(task_label,label) << " " << value << std::endl;
         return oss_.str();
       }
-      
+
       template <typename T> std::string var_declare_v(const std::string& label) {
         return ctext_->declare_v(ctext_->type_name<T>(),ctext_->label_to_name(label),macro("MAX_VECLEN"));
-      }      
-      
+      }
+
       private:
       std::string null_str_;
       std::ostringstream oss_;
@@ -119,7 +117,7 @@ namespace libint2 {
       std::string lf_decl_;   // _init_flopcounter
 
       typedef std::basic_ofstream<char> fstream;
-      
+
       fstream th_;
       fstream ph_;
       fstream ih_;
@@ -129,7 +127,7 @@ namespace libint2 {
       fstream li_;
 
       void generate_inteval_type(std::ostream& os);
-      
+
     };
 };
 
