@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2019 Edward F. Valeev
+ *  Copyright (C) 2004-2021 Edward F. Valeev
  *
  *  This file is part of Libint.
  *
@@ -24,8 +24,6 @@
 #include <generic_rr.h>
 #include <twoprep_11_11.h>
 
-using namespace std;
-
 namespace libint2 {
 
   /** VRR Recurrence Relation for 2-e ERI. part specifies for which particle
@@ -62,11 +60,11 @@ namespace libint2 {
       /** Re-Implementation of GenericRecurrenceRelation::generate_label():
           TwoPRep VRR recurrence relations codes are independent of m (it never appears anywhere in equations), hence
           to avoid generating identical code make sure that the (unique) label has m=0. */
-      std::string generate_label() const
+      std::string generate_label() const override
       {
         typedef typename TargetType::AuxIndexType mType;
         static SafePtr<mType> aux0(new mType(0u));
-        ostringstream os;
+        std::ostringstream os;
         os << descr() << "P" << part << to_string(where)
            << genintegralset_label(target_->bra(),target_->ket(),aux0,target_->oper());
         return os.str();
@@ -74,11 +72,11 @@ namespace libint2 {
 
   #if LIBINT_ENABLE_GENERIC_CODE
       /// Implementation of RecurrenceRelation::has_generic()
-      bool has_generic(const SafePtr<CompilationParameters>& cparams) const;
+      bool has_generic(const SafePtr<CompilationParameters>& cparams) const override;
       /// Implementation of RecurrenceRelation::generic_header()
-      std::string generic_header() const;
+      std::string generic_header() const override;
       /// Implementation of RecurrenceRelation::generic_instance()
-      std::string generic_instance(const SafePtr<CodeContext>& context, const SafePtr<CodeSymbols>& args) const;
+      std::string generic_instance(const SafePtr<CodeContext>& context, const SafePtr<CodeSymbols>& args) const override;
   #endif
     };
 
@@ -110,10 +108,10 @@ namespace libint2 {
       const OriginDerivative<3u> dB = Tint->ket(0,0).deriv();
       const OriginDerivative<3u> dC = Tint->bra(1,0).deriv();
       const OriginDerivative<3u> dD = Tint->ket(1,0).deriv();
-      const bool deriv = dA.zero() == false ||
-          dB.zero() == false ||
-          dC.zero() == false ||
-          dD.zero() == false;
+      const bool deriv = !dA.zero() ||
+          !dB.zero() ||
+          !dC.zero() ||
+          !dD.zero();
 
       // This is a hack to avoid creating recurrence relations for which generic code has not been yet implemented
 #if LIBINT_ENABLE_GENERIC_CODE
@@ -562,12 +560,12 @@ namespace libint2 {
       const OriginDerivative<3u> dB = target_->ket(0,0).deriv();
       const OriginDerivative<3u> dC = target_->bra(1,0).deriv();
       const OriginDerivative<3u> dD = target_->ket(1,0).deriv();
-      const bool deriv = dA.zero() == false ||
-          dB.zero() == false ||
-          dC.zero() == false ||
-          dD.zero() == false;
+      const bool deriv = !dA.zero() ||
+          !dB.zero() ||
+          !dC.zero() ||
+          !dD.zero();
 
-      if (deriv == false) {
+      if (!deriv) {
         if (xsxs) return std::string("OSVRR_xs_xs.h");
         if (sxsx) return std::string("OSVRR_sx_sx.h");
       }
@@ -612,14 +610,14 @@ namespace libint2 {
       const OriginDerivative<3u> dB = target_->ket(0,0).deriv();
       const OriginDerivative<3u> dC = target_->bra(1,0).deriv();
       const OriginDerivative<3u> dD = target_->ket(1,0).deriv();
-      const bool deriv = dA.zero() == false ||
-          dB.zero() == false ||
-          dC.zero() == false ||
-          dD.zero() == false;
+      const bool deriv = !dA.zero() ||
+          !dB.zero() ||
+          !dC.zero() ||
+          !dD.zero();
 
-      oss << "using namespace libint2;" << endl;
+      oss << "using namespace libint2;" << std::endl;
 
-      if (deriv == false) { // for regular integrals I know exactly how many prerequisites I need
+      if (!deriv) { // for regular integrals I know exactly how many prerequisites I need
         if(xsxs) {
           oss << "libint2::OS" << (ahlrichs_simplification ? "A" : "")
               << "VRR_xs_xs<" << part << "," << sh_a.norm() << "," << sh_c.norm() << ",";
