@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2019 Edward F. Valeev
+ *  Copyright (C) 2004-2020 Edward F. Valeev
  *
  *  This file is part of Libint.
  *
@@ -1141,9 +1141,9 @@ std::vector<Matrix> compute_1body_ints_deriv(unsigned deriv_order,
             // computes upper triangle index
             // n2 = matrix size times 2
             // i,j = (unordered) indices
-#define upper_triangle_index(n2, i, j) \
-  (std::min((i), (j))) * ((n2) - (std::min((i), (j))) - 1) / 2 + \
-            (std::max((i), (j)))
+            auto upper_triangle_index = [](long n2, long i, long j) {
+              return std::min(i, j) * (n2 - std::min(i, j) - 1) / 2 + std::max(i, j);
+            };
 
             // look over shellsets in the order in which they appear
             std::size_t shellset_idx = 0;
@@ -1174,7 +1174,6 @@ std::vector<Matrix> compute_1body_ints_deriv(unsigned deriv_order,
               }
             }
           } break;
-#undef upper_triangle_index
 
           default: {
             assert(false && "not yet implemented");
@@ -1251,7 +1250,7 @@ Matrix compute_schwarz_ints(
         assert(buf[0] != nullptr &&
                "to compute Schwarz ints turn off primitive screening");
 
-        // to apply Schwarz inequality to individual integrals must use the diagonal elements
+        // to apply Schwarz inequality to individual integrals must use the "diagonal" elements
         // to apply it to sets of functions (e.g. shells) use the whole shell-set of ints here
         Eigen::Map<const Matrix> buf_mat(buf[0], n12, n12);
         auto norm2 = use_2norm ? buf_mat.norm()
@@ -1286,7 +1285,7 @@ compute_shellpairs(const BasisSet& bs1,
 
   using libint2::nthreads;
 
-  // construct the 2-electron repulsion integrals engine
+  // construct the overlap integral engines
   using libint2::Engine;
   std::vector<Engine> engines;
   engines.reserve(nthreads);
@@ -1910,12 +1909,12 @@ std::vector<Matrix> compute_2body_fock_deriv(const BasisSet& obs,
               } break;
 
               case 2: {
-// computes upper triangle index
-// n2 = matrix size times 2
-// i,j = (unordered) indices
-#define upper_triangle_index(n2, i, j)                           \
-  (std::min((i), (j))) * ((n2) - (std::min((i), (j))) - 1) / 2 + \
-      (std::max((i), (j)))
+                // computes upper triangle index
+                // n2 = matrix size times 2
+                // i,j = (unordered) indices
+                auto upper_triangle_index = [](size_t n2, size_t i, size_t j) {
+                  return std::min(i, j) * (n2 - (std::min(i, j)) - 1) / 2 + std::max(i, j);
+                };
                 // look over shellsets in the order in which they appear
                 std::size_t shellset_idx = 0;
                 for (auto c1 = 0; c1 != 4; ++c1) {
@@ -1941,7 +1940,6 @@ std::vector<Matrix> compute_2body_fock_deriv(const BasisSet& obs,
                   }
                 }
               } break;
-#undef upper_triangle_index
 
               default:
                 assert(deriv_order <= 2 &&
